export type ItemQuality = 'wood' | 'iron' | 'silver' | 'gold' | 'diamond'
export type ItemType = 'tool' | 'weapon' | 'block' | 'ore'

export type DropItem =
  | 'Shovel' | 'Pick Axe' | 'Sword'
  | 'leaves' | 'dirt' | 'wood' | 'stone' | 'gravel'
  | 'coal' | 'iron' | 'silver' | 'gold' | 'ruby' | 'diamond' | 'emerald'

export interface Item {
  name: DropItem
  type: ItemType
  icon: string
  hasQuality?: boolean
  builds?: BlockType
}

export type Block = {
  type: string,          // what is it?
  hp: number,            // how long do I need to hit it?
  walkable: boolean,     // can I walk through it?
  climbable?: boolean,   // can I climb it?
  transparent?: boolean, // can I see through it?
  illuminated?: boolean, // is it glowing?
  drops?: DropItem,      // what do I get, when loot it?
}

export type BlockType =
  | 'air' | 'grass'
  | 'treeCrown' | 'treeLeaves' | 'treeTrunk' | 'treeRoot'
  | 'soil' | 'soilGravel' | 'stone' | 'stoneGravel'
  | 'bedrock' | 'cave'
  | 'brickWall'

export interface InventoryItem extends Item {
  amount: number
  quality: ItemQuality | null
}

export interface Moveable {
  x: number // position on x-axis (fixed for the player)
  y: number // position on y-axis (fixed for the player)
  lastDir: number // store last face direction
  vx: number // velocity on the x-axis
  vy: number // velocity on the y-axis
}

export interface Npc extends Moveable {
  hostile: boolean
  inventory: InventoryItem[]
}

export interface Player extends Moveable {
  inventory: InventoryItem[]
}
